# skip tests known to be problematic in a specific version
%global skip_checks_version 0.1.90
%ifarch %arm
%global skip_checks cairo_cmyk_hack cairo-RGB24 format_with_space srgb_to_lab_u8 xyz_to_lab conversions
%else
%global skip_checks %nil
%endif

%define major     0
%define api       0.1
%define libname   %mklibname babl %{api} %{major}
%define girname   %mklibname babl-gir %{api}
%define develname %mklibname babl %{api} -d

%define url_ver %(echo %{version}|cut -d. -f1,2)

Name:           babl
Epoch:          1
Version:        0.1.102
Release:        %mkrel 2
Summary:        Dynamic, any to any, pixel format conversion library
Group:          System/Libraries
License:        LGPLv3+
URL:            https://www.gegl.org/babl
Source0:        https://download.gimp.org/pub/%{name}/%{url_ver}/%{name}-%{version}.tar.xz
BuildRequires:  librsvg
BuildRequires:  meson
BuildRequires:  pkgconfig(appstream)
BuildRequires:  pkgconfig(appstream-glib)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  vala-tools

%description
Babl is a dynamic, any to any, pixel format conversion library.
It provides conversions between the myriad of buffer types images
can be stored in. Babl doesn't only help with existing pixel formats,
but also facilitates creation of new and uncommon ones.

GEGL uses babl both for enumeration of pixel formats as well as
conversions between them.

%package -n     %{libname}
Summary:        A library for %{name}
Group:          System/Libraries

%description -n %{libname}
Babl is a dynamic, any to any, pixel format conversion library.
It provides conversions between the myriad of buffer types images
can be stored in. Babl doesn't only help with existing pixel formats,
but also facilitates creation of new and uncommon ones.

GEGL uses babl both for enumeration of pixel formats as well as
conversions between them.

%package -n %{girname}
Summary:    GObject Introspection interface description for Babl
Requires:   %{libname} = %{epoch}:%{version}-%{release}
Conflicts:  %{_lib}babl0.1-devel < 1:0.1.78-2

%description -n %{girname}
GObject Introspection interface description for Babl.

%package -n     %{develname}
Summary:        Header files for %{name}
Group:          Development/C
Requires:       %{libname} = %{epoch}:%{version}-%{release}
Requires:       %{girname} = %{epoch}:%{version}-%{release}
Provides:       lib%{name}-devel = %{epoch}:%{version}-%{release}
Provides:       %{name}-devel = %{epoch}:%{version}-%{release}

%description -n %{develname}
Babl is a dynamic, any to any, pixel format conversion library.
It provides conversions between the myriad of buffer types images
can be stored in. Babl doesn't only help with existing pixel formats,
but also facilitates creation of new and uncommon ones.

GEGL uses babl both for enumeration of pixel formats as well as
conversions between them.

%prep
%autosetup -p1

%build
%meson -Denable-vapi=true \
%ifarch %{ix86}
	-Denable-mmx=false \
	-Denable-sse=false \
	-Denable-sse2=false \
	-Denable-sse4_1=false \
	-Denable-avx2=false \
	-Denable-f16c=false \
%endif
	-Denable-gir=true
%meson_build

%install
rm -fr %{buildroot} installed-docs
%meson_install

cp -r docs installed-docs
cd installed-docs
rm -f "%{buildroot}/%{develdocdir}"/graphics/meson.build
rm -f "%{buildroot}/%{develdocdir}"/graphics/.gitignore


%check
# skip tests known to be problematic in a specific version
%if "%version" == "%skip_checks_version"
pushd build/tests
for problematic in %skip_checks; do
    rm -f "$problematic"
        cat << EOF > "$problematic"
#!/bin/sh
echo Skipping test "$problematic"
EOF
chmod +x "$problematic"
done
popd
%endif
%meson_test

%files
%{_bindir}/babl

%files -n %{libname}
%doc NEWS TODO AUTHORS
%{_libdir}/libbabl-%{api}.so.%{major}{,.*}
%dir %{_libdir}/babl-%{api}/
%{_libdir}/babl-%{api}/cairo.so
%{_libdir}/babl-%{api}/CIE.so
%{_libdir}/babl-%{api}/double.so
%{_libdir}/babl-%{api}/fast-float.so
%{_libdir}/babl-%{api}/float.so
%{_libdir}/babl-%{api}/gegl-fixups.so
%{_libdir}/babl-%{api}/gggl-lies.so
%{_libdir}/babl-%{api}/gggl.so
%{_libdir}/babl-%{api}/gggl-table-lies.so
%{_libdir}/babl-%{api}/gggl-table.so
%{_libdir}/babl-%{api}/gimp-8bit.so
%{_libdir}/babl-%{api}/grey.so
%{_libdir}/babl-%{api}/half.so
%{_libdir}/babl-%{api}/HCY.so
%{_libdir}/babl-%{api}/HSL.so
%{_libdir}/babl-%{api}/HSV.so
%{_libdir}/babl-%{api}/naive-CMYK.so
%{_libdir}/babl-%{api}/oklab.so
%{_libdir}/babl-%{api}/simple.so
%{_libdir}/babl-%{api}/avx2-int8.so
%{_libdir}/babl-%{api}/sse2-float.so
%{_libdir}/babl-%{api}/sse2-int16.so
%{_libdir}/babl-%{api}/sse2-int8.so
%{_libdir}/babl-%{api}/sse4-int8.so
%{_libdir}/babl-%{api}/sse-half.so
%{_libdir}/babl-%{api}/two-table.so
%{_libdir}/babl-%{api}/u16.so
%{_libdir}/babl-%{api}/u32.so
%{_libdir}/babl-%{api}/ycbcr.so
%ifarch x86_64
%{_libdir}/babl-%{api}/x86-64-*.so
%endif
%ifarch %arm
%{_libdir}/babl-%{api}/arm-*.so
%endif

%files -n %{girname}
%{_libdir}/girepository-1.0/Babl-%{api}.typelib

%files -n %{develname}
%doc installed-docs/*
%{_libdir}/libbabl-%{api}.so
%{_libdir}/pkgconfig/babl-%{api}.pc
%dir %{_includedir}/babl-%{api}
%dir %{_includedir}/babl-%{api}/babl
%{_includedir}/babl-%{api}/babl/*
%{_datadir}/gir-1.0/Babl-%{api}.gir
%{_datadir}/vala/vapi/babl-0.1.deps
%{_datadir}/vala/vapi/babl-0.1.vapi


%changelog
* Thu May 04 2023 daviddavid <daviddavid> 1:0.1.102-2.mga9
+ Revision: 1955831
- fix owner of include dir

* Mon Mar 06 2023 daviddavid <daviddavid> 1:0.1.102-1.mga9
+ Revision: 1947936
- new version: 0.1.102 (fixes text colour regression mga#31627)

* Wed Feb 22 2023 kekepower <kekepower> 1:0.1.100-1.mga9
+ Revision: 1944656
- Fix file list
- Update to version 0.1.100

* Mon Nov 14 2022 kekepower <kekepower> 1:0.1.98-1.mga9
+ Revision: 1907268
- Update to version 0.1.98

* Mon Sep 05 2022 tv <tv> 1:0.1.96-1.mga9
+ Revision: 1883965
- Fix filelist
- 0.1.96

* Tue Jul 19 2022 papoteur <papoteur> 1:0.1.92-3.mga9
+ Revision: 1869475
- Fix build with new meson

* Mon Apr 04 2022 pterjan <pterjan> 1:0.1.92-2.mga9
+ Revision: 1843964
- Fix file list on arm

* Mon Apr 04 2022 tv <tv> 1:0.1.92-1.mga9
+ Revision: 1843679
- New upstream release 0.1.92

* Sun Mar 20 2022 tv <tv> 1:0.1.90-4.mga9
+ Revision: 1802237
- Fix ignoring problematic tests on armv7hl

* Sun Mar 20 2022 tv <tv> 1:0.1.90-3.mga9
+ Revision: 1802102
- Ignore problematic tests on armv7hl

* Sun Mar 20 2022 tv <tv> 1:0.1.90-2.mga9
+ Revision: 1802067
- Rebuild because latest version didn't make it on armv7hl

* Mon Mar 07 2022 tv <tv> 1:0.1.90-1.mga9
+ Revision: 1789469
- 0.1.90
+ wally <wally>
- drop old obsoletes

* Wed Jan 05 2022 wally <wally> 1:0.1.88-2.mga9
+ Revision: 1767078
- fix meson build option
- rebuild for appstream 0.15.1 with vala files moved to devel pkg

* Tue Jul 06 2021 kekepower <kekepower> 1:0.1.88-1.mga9
+ Revision: 1734958
- Update to version 0.1.88

* Sat Mar 27 2021 kekepower <kekepower> 1:0.1.86-1.mga9
+ Revision: 1711139
- Update to version 0.1.86

* Thu Mar 11 2021 ghibo <ghibo> 1:0.1.84-2.mga9
+ Revision: 1701478
- Fix invalid instructions (MMX, SSE, SSE2, SSE4.1, AVX2, F16C) on pure i586 arch.

* Wed Dec 30 2020 luigiwalser <luigiwalser> 1:0.1.84-1.mga8
+ Revision: 1665824
- 0.1.84

* Sun Oct 25 2020 shlomif <shlomif> 1:0.1.82-1.mga8
+ Revision: 1639317
- New version 0.1.82

* Mon Jun 08 2020 wally <wally> 1:0.1.78-3.mga8
+ Revision: 1591050
- add missing epoch to requires and provides

* Mon Jun 08 2020 wally <wally> 1:0.1.78-2.mga8
+ Revision: 1591045
- split out gir typelib

* Mon Jun 08 2020 daviddavid <daviddavid> 1:0.1.78-1.mga8
+ Revision: 1591028
- new version: 0.1.78

* Wed Apr 15 2020 danf <danf> 1:0.1.74-4.mga8
+ Revision: 1567661
- Add a BuildRequires: to fix building

* Tue Mar 03 2020 tv <tv> 1:0.1.74-3.mga8
+ Revision: 1553405
- do not ship meson.build & .gitignore

* Fri Feb 21 2020 umeabot <umeabot> 1:0.1.74-2.mga8
+ Revision: 1547903
- Mageia 8 Mass Rebuild

* Tue Feb 11 2020 daviddavid <daviddavid> 1:0.1.74-1.mga8
+ Revision: 1488661
- new version: 0.1.74

* Mon Nov 04 2019 daviddavid <daviddavid> 1:0.1.72-1.mga8
+ Revision: 1457575
- fix release tag

* Mon Oct 28 2019 tv <tv> 1:0.1.72-0.1.mga8
+ Revision: 1456212
- adjust file list (pour gir/typelib in devel pkg)
- switch to meson
- new release

* Sat Jun 29 2019 shlomif <shlomif> 1:0.1.66-1.mga8
+ Revision: 1415980
- New version 0.1.66

* Sat Feb 16 2019 luigiwalser <luigiwalser> 1:0.1.62-1.mga7
+ Revision: 1367608
- 0.1.62

* Fri Dec 28 2018 luigiwalser <luigiwalser> 1:0.1.60-1.mga7
+ Revision: 1345824
- 0.1.60

* Fri Nov 09 2018 kekepower <kekepower> 1:0.1.58-1.mga7
+ Revision: 1329028
- Update to version 0.1.58

* Fri Sep 21 2018 umeabot <umeabot> 1:0.1.56-2.mga7
+ Revision: 1295252
- Mageia 7 Mass Rebuild

* Mon Aug 20 2018 tv <tv> 1:0.1.56-1.mga7
+ Revision: 1252955
- new release

* Thu Jul 05 2018 shlomif <shlomif> 1:0.1.52-1.mga7
+ Revision: 1241819
- New version 0.1.52

* Sun May 20 2018 kekepower <kekepower> 1:0.1.50-1.mga7
+ Revision: 1230824
- Update to version 0.1.50
+ tv <tv>
- use %%autosetup

* Wed Apr 18 2018 shlomif <shlomif> 1:0.1.46-1.mga7
+ Revision: 1219811
- New version 0.1.46

* Tue Mar 27 2018 kekepower <kekepower> 1:0.1.44-1.mga7
+ Revision: 1212918
- Update to version 0.1.44

* Fri Feb 16 2018 ovitters <ovitters> 1:0.1.42-1.mga7
+ Revision: 1201641
- new version 0.1.42

* Fri Feb 16 2018 ovitters <ovitters> 1:0.1.38-1.mga7
+ Revision: 1201636
- new version 0.1.38

* Wed Aug 23 2017 ovitters <ovitters> 1:0.1.30-1.mga7
+ Revision: 1143634
- new version 0.1.30

* Tue May 23 2017 luigiwalser <luigiwalser> 1:0.1.26-1.mga6
+ Revision: 1104226
- 0.1.26

* Wed Feb 15 2017 luigiwalser <luigiwalser> 1:0.1.24-1.mga6
+ Revision: 1086216
- 0.1.24

* Sun Jan 01 2017 luigiwalser <luigiwalser> 1:0.1.22-1.mga6
+ Revision: 1078946
- 0.1.22

* Sat Nov 12 2016 luigiwalser <luigiwalser> 1:0.1.20-1.mga6
+ Revision: 1066629
- 0.1.20

* Thu Aug 11 2016 luigiwalser <luigiwalser> 1:0.1.18-1.mga6
+ Revision: 1045500
- 0.1.18

* Fri Mar 11 2016 wally <wally> 1:0.1.16-1.mga6
+ Revision: 989271
- new version 0.1.16

* Mon Dec 21 2015 tv <tv> 1:0.1.14-1.mga6
+ Revision: 912936
- fix file list
- new release

* Wed Jun 24 2015 shlomif <shlomif> 1:0.1.12-2.mga6
+ Revision: 842316
- .spec cleanups + failing test
+ ovitters <ovitters>
- new version 0.1.12

* Wed Oct 15 2014 umeabot <umeabot> 1:0.1.10-7.mga5
+ Revision: 741000
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1:0.1.10-6.mga5
+ Revision: 693474
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1:0.1.10-5.mga5
+ Revision: 678093
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1:0.1.10-4.mga4
+ Revision: 502987
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 1:0.1.10-3.mga3
+ Revision: 346824
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jul 28 2012 sander85 <sander85> 1:0.1.10-2.mga3
+ Revision: 275309
- Skip tests known to be problematic (from Fedora)

* Thu May 03 2012 fwang <fwang> 1:0.1.10-1.mga2
+ Revision: 234572
- new version 0.1.10

* Tue Nov 29 2011 fwang <fwang> 1:0.1.6-1.mga2
+ Revision: 174037
- new version 0.1.6

* Thu Jun 30 2011 ahmad <ahmad> 1:0.1.4-1.mga2
+ Revision: 116363
- Update to 0.1.4

* Wed Jan 19 2011 ahmad <ahmad> 1:0.1.2-3.mga1
+ Revision: 24709
- imported package babl


* Tue Nov 30 2010 Oden Eriksson <oeriksson@mandriva.com> 1:0.1.2-2mdv2011.0
+ Revision: 603754
- rebuild

* Sat Feb 13 2010 Emmanuel Andry <eandry@mandriva.org> 1:0.1.2-1mdv2010.1
+ Revision: 505542
- New version 0.1.2
- use api major
- drop patch (now useless)
- remove static
- enable check
- update files list

* Tue Jul 07 2009 Götz Waschk <waschk@mandriva.org> 1:0.1.0-1mdv2010.0
+ Revision: 393147
- new version
- source URL
- update file list
- fix installation

* Tue Apr 07 2009 Funda Wang <fwang@mandriva.org> 1:0.0.22-1mdv2009.1
+ Revision: 364695
- fix str fmt

* Tue Jun 24 2008 Götz Waschk <waschk@mandriva.org> 1:0.0.22-1mdv2009.0
+ Revision: 228534
- new version
- fix spec file mess
- move modules to the library package
- add documentation

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed Apr 16 2008 Emmanuel Andry <eandry@mandriva.org> 1:0.0.20-3mdv2009.0
+ Revision: 194643
- Add needed provides

* Wed Apr 16 2008 Emmanuel Andry <eandry@mandriva.org> 1:0.0.20-2mdv2009.0
+ Revision: 194610
- Fix devel package
- obsolete wrong majors

* Fri Apr 11 2008 Emmanuel Andry <eandry@mandriva.org> 1:0.0.20-1mdv2009.0
+ Revision: 192590
- New version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Nicolas Lécureuil <nlecureuil@mandriva.com>
    - Fix %%major (tks misc)

* Wed Jun 13 2007 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.0.14-1mdv2008.0
+ Revision: 38582
- Import babl

